//
//  currentTrack.h
//  butt
//
//  Created by Melchor Garau Madrigal on 22/7/15.
//  Copyright (c) 2015 Daniel Nöthen. All rights reserved.
//

#ifndef __butt__currentTrack__
#define __butt__currentTrack__

#include <stdio.h>
typedef const char* (*currentTrackFunction)(int artist_title_order);

#endif /* defined(__butt__currentTrack__) */
